@@ -232,26 +232,28 @@ def _PyScons(env, target, source, scons, execute=None, options="-Q", sig_options
     if tempdir == None:
         m = hashlib.sha1()
         m.update(sig)
-        TEMP = os.path.join("temp", base64.b64encode(m.digest(), "+="), '')
-    else: TEMP = tempdir
+        basename = os.path.join("temp", base64.b64encode(m.digest(), "+="), '')
+    else: basename = tempdir
 
-    options += " temp=" + TEMP + " n=" + scons  
+    options += " temp=" + basename + " n=" + scons  
     cmd = "scons %s %s -f%s %s" % (options, sig_options, scons, args)
     cleancmd = cmd + " --clean"
 
-    exe = os.path.join(tempdir, "EXECUTE")
+    env.Execute(Mkdir(basename))
+    exe = os.path.join(basename, "EXECUTE")
     file = open(exe, 'w')
     print >>file, "#!/bin/bash"
     print >>file, cmd + " $*"
     os.chmod(exe, 0755)
+    file.close()
 
     if env.GetOption("clean") and not clean: 
         env.Execute(cleancmd)
-        env.Execute(Delete(TEMP))
+        env.Execute(Delete(basename))
 
-    if not execute: cmd = [Mkdir(TEMP), cmd]
-    else: cmd = [execute + " " + tempdir]
-    if clean: cmd += [Delete(TEMP)]
+    if not execute: cmd = [cmd]
+    else: cmd = [execute + " " + basename]
+    if clean: cmd += [Delete(basename)]
 
     gen = lambda source, target, env, for_signature: sig if for_signature else cmd 
     return env.Command(target, source + [scons], CommandGeneratorAction(gen,{}))
@@ -312,16 +314,23 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
             shutil.move(f,t)
         env.Exit(0)
 
-
     ship = os.path.join(basename, "SHIP.tz2")
     out = os.path.join(basename, "OUT.tz2")
+    force = os.path.join(basename, "IN.tz2")
+    exe = os.path.join(basename, "EXECUTE")
+
+    if os.path.exists(force):
+        import subprocess
+        print "tar xjf %s" % force
+        subprocess.call(["tar xjf ", force])
+        print "Move(%s,%s)" % (force, out)
+        shutil.mv(force, out)
+        env.Exit(0)
 
     env.Command(ship, sources, "tar cjf $TARGET $SOURCES")
-
     env.Default(targets)
-
     SIGNATURES = os.path.join(basename, ".sconsign.dblite")
-    env.Command(out, targets, "tar cjf $TARGET $SOURCES")
+    env.Command(out, targets + [exe], "tar cjf $TARGET $SOURCES")
 
     return targets, sources, basename
 
